Changelog
=========

Version 0.1.3
-------------

Bug fixes
~~~~~~~~~

- Ignore ``skip_empty`` in ``utils.smart_concat()`` when all the DataFrames are empty.

Version 0.1.2
-------------

Improvements
~~~~~~~~~~~~

- Use ``skip_empty=True`` by default in ``utils.smart_concat()``.

Version 0.1.1
-------------

Improvements
~~~~~~~~~~~~

- Update documentation.

Version 0.1.0
-------------

New Features
~~~~~~~~~~~~

- First release, split from BlueETL 0.3.0.dev3.
